@@ -3,7 +3,7 @@ package Firefox::Marionette::Element::Rect;
 use strict;
 use warnings;
 
-our $VERSION = '0.98_07';
+our $VERSION = '0.01';
 
 sub new {
     my ( $class, %parameters ) = @_;
@@ -40,7 +40,7 @@ Firefox::Marionette::Element::Rect - Represents the box around an Element
 
 =head1 VERSION
 
-Version 0.98_07
+Version 0.1
 
 =head1 SYNOPSIS
 
@@ -48,8 +48,8 @@ Version 0.98_07
     use v5.10;
 
     my $firefox = Firefox::Marionette->new()->go('https://metacpan.org/');
-    my $rect = $firefox->find('//button[@name="lucky"]')->rect();
-    say "Current height of the Lucky button " . $rect->height();
+    my $rect = $firefox->find_element('//button[@name="lucky"]')->rect();
+    say "Current height of the Lucky button " . $cookie->height();
 
 =head1 DESCRIPTION
 
@@ -73,7 +73,7 @@ accepts a hash as a parameter.  Allowed keys are below;
 
 =back
 
-This method returns a new L<rect|Firefox::Marionette::Element::Rect> object.
+This method returns a new L<cookie|Firefox::Marionette::Element::Rect> object.
  
 =head2 pos_x
 
@@ -121,7 +121,7 @@ David Dick  C<< <ddick@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2020, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
+Copyright (c) 2018, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic/perlartistic>.
