@@ -3,11 +3,13 @@ package Firefox::Marionette::Timeouts;
 use strict;
 use warnings;
 
-our $VERSION = '0.98_07';
+our $VERSION = '0.01';
 
 sub new {
     my ( $class, %parameters ) = @_;
-    my $element = bless {%parameters}, $class;
+    my $element = bless {
+        %parameters
+    }, $class;
     return $element;
 }
 
@@ -35,7 +37,7 @@ Firefox::Marionette::Timeouts - Represents the timeouts for page loading, search
 
 =head1 VERSION
 
-Version 0.98_07
+Version 0.1
 
 =head1 SYNOPSIS
 
@@ -60,9 +62,9 @@ accepts a hash as a parameter.  Allowed keys are below;
 
 =item * page_load - the timeout used for L<go|Firefox::Marionette#go>, L<back|Firefox::Marionette#back>, L<forward|Firefox::Marionette#forward>, L<refresh|Firefox::Marionette#refresh> and L<click|Firefox::Marionette#click> methods in milliseconds
 
-=item * script - the timeout used for L<script|Firefox::Marionette#script> and L<async_script|Firefox::Marionette#async_script> methods in milliseconds
+=item * scripts - the timeout used for L<script|Firefox::Marionette#script> and L<async_script|Firefox::Marionette#async_script> methods in milliseconds
 
-=item * implicit - the timeout used for L<find|Firefox::Marionette#find> and L<list|Firefox::Marionette#list> methods in milliseconds
+=item * implicit - the timeout used for L<find_element|Firefox::Marionette#find_element> and L<find_elements|Firefox::Marionette#find_elements> methods in milliseconds
 
 =back
 
@@ -72,13 +74,13 @@ This method returns a new L<timeout|Firefox::Marionette::Timeout> object.
 
 returns the the timeout used for L<go|Firefox::Marionette#go>, L<back|Firefox::Marionette#back>, L<forward|Firefox::Marionette#forward>, L<refresh|Firefox::Marionette#refresh> and L<click|Firefox::Marionette#click> methods in milliseconds.
 
-=head2 script
+=head2 scripts
 
 returns the the timeout used for L<script|Firefox::Marionette#script> and L<async_script|Firefox::Marionette#async_script> methods in milliseconds.
 
 =head2 implicit
 
-returns the timeout used for L<find|Firefox::Marionette#find> and L<list|Firefox::Marionette#list> methods in milliseconds
+returns the timeout used for L<find_element|Firefox::Marionette#find_element> and L<find_elements|Firefox::Marionette#find_elements> methods in milliseconds
 
 =head1 DIAGNOSTICS
 
@@ -110,7 +112,7 @@ David Dick  C<< <ddick@cpan.org> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (c) 2020, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
+Copyright (c) 2018, David Dick C<< <ddick@cpan.org> >>. All rights reserved.
 
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic/perlartistic>.
